////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  depth_1_0_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "depth_1_0_0.h"
#include "parametersetmanager.h"

DEPTH_1_0_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "reprojection") == 0)
    {
        __result = reprojection.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_disparity") == 0)
    {
        __result = calc_focus_disparity.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_roi") == 0)
    {
        __result = calc_focus_roi.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_depth10_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "reprojection") == 0)
    {
        __result = reprojection.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_disparity") == 0)
    {
        __result = calc_focus_disparity.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_roi") == 0)
    {
        __result = calc_focus_roi.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_depth10_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // top
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("top", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.GetInfo(&__path[__pos], __info);
    }

    // reprojection
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reprojection", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "reprojection") == 0)
    {
        __result = reprojection.GetInfo(&__path[__pos], __info);
    }

    // calc_focus_disparity
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("calc_focus_disparity", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_disparity") == 0)
    {
        __result = calc_focus_disparity.GetInfo(&__path[__pos], __info);
    }

    // calc_focus_roi
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("calc_focus_roi", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_roi") == 0)
    {
        __result = calc_focus_roi.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "dfs_width_tab") == 0)
    {
        __result = dfs_width_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "dfs_height_tab") == 0)
    {
        __result = dfs_height_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "dfs_max_extra_scale_x") == 0)
    {
        ParameterUtils::DoubleToString((double)dfs_max_extra_scale_x, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dfs_max_extra_scale_y") == 0)
    {
        ParameterUtils::DoubleToString((double)dfs_max_extra_scale_y, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aux_margin_ratio") == 0)
    {
        ParameterUtils::DoubleToString((double)aux_margin_ratio, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved7") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved7, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved8") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved8, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved9") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved9, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved10") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved10, __value, __size);
        __result = true;
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "dfs_width_tab") == 0)
    {
        __result = dfs_width_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "dfs_height_tab") == 0)
    {
        __result = dfs_height_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "dfs_max_extra_scale_x") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dfs_max_extra_scale_x = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dfs_max_extra_scale_y") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dfs_max_extra_scale_y = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aux_margin_ratio") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aux_margin_ratio = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved7") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved7 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved8") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved8 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved9") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved9 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved10") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved10 = (float)dblValue; 
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // dfs_width_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dfs_width_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "dfs_width_tab") == 0)
    {
        __result = dfs_width_tab.GetInfo(&__path[__pos], __info);
    }

    // dfs_height_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dfs_height_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "dfs_height_tab") == 0)
    {
        __result = dfs_height_tab.GetInfo(&__path[__pos], __info);
    }

    // dfs_max_extra_scale_x
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dfs_max_extra_scale_x", ParameterParserDataType::Float, (double)dfs_max_extra_scale_x));
    }
    else if (PARAMETER_STRCMP(__name, "dfs_max_extra_scale_x") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)dfs_max_extra_scale_x));
    }

    // dfs_max_extra_scale_y
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dfs_max_extra_scale_y", ParameterParserDataType::Float, (double)dfs_max_extra_scale_y));
    }
    else if (PARAMETER_STRCMP(__name, "dfs_max_extra_scale_y") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)dfs_max_extra_scale_y));
    }

    // aux_margin_ratio
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aux_margin_ratio", ParameterParserDataType::Float, (double)aux_margin_ratio));
    }
    else if (PARAMETER_STRCMP(__name, "aux_margin_ratio") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)aux_margin_ratio));
    }

    // reserved7
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved7", ParameterParserDataType::Float, (double)reserved7));
    }
    else if (PARAMETER_STRCMP(__name, "reserved7") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved7));
    }

    // reserved8
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved8", ParameterParserDataType::Float, (double)reserved8));
    }
    else if (PARAMETER_STRCMP(__name, "reserved8") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved8));
    }

    // reserved9
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved9", ParameterParserDataType::Float, (double)reserved9));
    }
    else if (PARAMETER_STRCMP(__name, "reserved9") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved9));
    }

    // reserved10
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved10", ParameterParserDataType::Float, (double)reserved10));
    }
    else if (PARAMETER_STRCMP(__name, "reserved10") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved10));
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::dfs_width_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "dfs_width") == 0)
    {
        if (__index < 3)
        {
            ParameterUtils::DoubleToString((double)dfs_width[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 3; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)dfs_width[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::dfs_width_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "dfs_width") == 0)
    {
        if (__index < 3)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                dfs_width[__index] = (UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 3)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    dfs_width[__index] = (UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::dfs_width_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // dfs_width
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dfs_width", ParameterParserDataType::UInt32, true, false, 3));
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::dfs_height_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "dfs_height") == 0)
    {
        if (__index < 3)
        {
            ParameterUtils::DoubleToString((double)dfs_height[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 3; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)dfs_height[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::dfs_height_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "dfs_height") == 0)
    {
        if (__index < 3)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                dfs_height[__index] = (UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 3)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    dfs_height[__index] = (UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::topStruct::dfs_height_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // dfs_height
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dfs_height", ParameterParserDataType::UInt32, true, false, 3));
    }

    return __result;
}

bool chromatix_depth10_reserveType::reprojectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_lmc_lut_en") == 0)
    {
        ParameterUtils::DoubleToString((double)ctc_lmc_lut_en, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_depth_min") == 0)
    {
        ParameterUtils::DoubleToString((double)ctc_lmc_depth_min, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_depth_mult") == 0)
    {
        ParameterUtils::DoubleToString((double)ctc_lmc_depth_mult, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_lut_data_tab") == 0)
    {
        __result = ctc_lmc_lut_data_tab.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_depth10_reserveType::reprojectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_lmc_lut_en") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ctc_lmc_lut_en = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_depth_min") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ctc_lmc_depth_min = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_depth_mult") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            ctc_lmc_depth_mult = (UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_lut_data_tab") == 0)
    {
        __result = ctc_lmc_lut_data_tab.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_depth10_reserveType::reprojectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ctc_lmc_lut_en
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_lmc_lut_en", ParameterParserDataType::UInt32, (double)ctc_lmc_lut_en, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_lut_en") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)ctc_lmc_lut_en, 0));
    }

    // ctc_lmc_depth_min
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_lmc_depth_min", ParameterParserDataType::UInt32, (double)ctc_lmc_depth_min, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_depth_min") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)ctc_lmc_depth_min, 0));
    }

    // ctc_lmc_depth_mult
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_lmc_depth_mult", ParameterParserDataType::UInt32, (double)ctc_lmc_depth_mult, 0));
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_depth_mult") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)ctc_lmc_depth_mult, 0));
    }

    // ctc_lmc_lut_data_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_lmc_lut_data_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "ctc_lmc_lut_data_tab") == 0)
    {
        __result = ctc_lmc_lut_data_tab.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_depth10_reserveType::reprojectionStruct::ctc_lmc_lut_data_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_lmc_lut_data") == 0)
    {
        if (__index < 65)
        {
            ParameterUtils::DoubleToString((double)ctc_lmc_lut_data[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 65; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)ctc_lmc_lut_data[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::reprojectionStruct::ctc_lmc_lut_data_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "ctc_lmc_lut_data") == 0)
    {
        if (__index < 65)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                ctc_lmc_lut_data[__index] = (INT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 65)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    ctc_lmc_lut_data[__index] = (INT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::reprojectionStruct::ctc_lmc_lut_data_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // ctc_lmc_lut_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("ctc_lmc_lut_data", ParameterParserDataType::Int32, true, false, 65));
    }

    return __result;
}

bool chromatix_depth10_reserveType::calc_focus_disparityStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "focus_disparity_calc_mode") == 0)
    {
        ParameterUtils::DoubleToString((double)focus_disparity_calc_mode, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_depth10_reserveType::calc_focus_disparityStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "focus_disparity_calc_mode") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            focus_disparity_calc_mode = (UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::calc_focus_disparityStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // focus_disparity_calc_mode
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("focus_disparity_calc_mode", ParameterParserDataType::UInt32, (double)focus_disparity_calc_mode, 0));
    }
    else if (PARAMETER_STRCMP(__name, "focus_disparity_calc_mode") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)focus_disparity_calc_mode, 0));
    }

    return __result;
}

bool chromatix_depth10_reserveType::calc_focus_roiStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mask_size") == 0)
    {
        ParameterUtils::DoubleToString((double)mask_size, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_depth10_reserveType::calc_focus_roiStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mask_size") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            mask_size = (UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_depth10_reserveType::calc_focus_roiStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mask_size
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mask_size", ParameterParserDataType::UInt32, (double)mask_size, 0));
    }
    else if (PARAMETER_STRCMP(__name, "mask_size") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)mask_size, 0));
    }

    return __result;
}

bool depth10_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_roi") == 0)
    {
        __result = calc_focus_roi.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool depth10_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_roi") == 0)
    {
        __result = calc_focus_roi.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool depth10_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // top
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("top", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "top") == 0)
    {
        __result = top.GetInfo(&__path[__pos], __info);
    }

    // calc_focus_roi
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("calc_focus_roi", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "calc_focus_roi") == 0)
    {
        __result = calc_focus_roi.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool depth10_rgn_dataType::topStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "reserved1") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved1, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved2") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved2, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved3") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved3, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved4") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved4, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved5") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved5, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved6") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved6, __value, __size);
        __result = true;
    }

    return __result;
}

bool depth10_rgn_dataType::topStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "reserved1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved1 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved2") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved2 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved3") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved3 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved4") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved4 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved5") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved5 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved6") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved6 = (float)dblValue; 
        }
    }

    return __result;
}

bool depth10_rgn_dataType::topStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // reserved1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved1", ParameterParserDataType::Float, (double)reserved1));
    }
    else if (PARAMETER_STRCMP(__name, "reserved1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved1));
    }

    // reserved2
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved2", ParameterParserDataType::Float, (double)reserved2));
    }
    else if (PARAMETER_STRCMP(__name, "reserved2") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved2));
    }

    // reserved3
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved3", ParameterParserDataType::Float, (double)reserved3));
    }
    else if (PARAMETER_STRCMP(__name, "reserved3") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved3));
    }

    // reserved4
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved4", ParameterParserDataType::Float, (double)reserved4));
    }
    else if (PARAMETER_STRCMP(__name, "reserved4") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved4));
    }

    // reserved5
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved5", ParameterParserDataType::Float, (double)reserved5));
    }
    else if (PARAMETER_STRCMP(__name, "reserved5") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved5));
    }

    // reserved6
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved6", ParameterParserDataType::Float, (double)reserved6));
    }
    else if (PARAMETER_STRCMP(__name, "reserved6") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved6));
    }

    return __result;
}

bool depth10_rgn_dataType::calc_focus_roiStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "min_focus_val") == 0)
    {
        ParameterUtils::DoubleToString((double)min_focus_val, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "max_focus_val") == 0)
    {
        ParameterUtils::DoubleToString((double)max_focus_val, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "smooth_alpha") == 0)
    {
        ParameterUtils::DoubleToString((double)smooth_alpha, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "min_valid_confidence") == 0)
    {
        ParameterUtils::DoubleToString((double)min_valid_confidence, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool depth10_rgn_dataType::calc_focus_roiStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "min_focus_val") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            min_focus_val = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "max_focus_val") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            max_focus_val = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "smooth_alpha") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            smooth_alpha = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "min_valid_confidence") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            min_valid_confidence = (float)dblValue; 
        }
    }

    return __result;
}

bool depth10_rgn_dataType::calc_focus_roiStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // min_focus_val
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("min_focus_val", ParameterParserDataType::Int32, (double)min_focus_val, 0));
    }
    else if (PARAMETER_STRCMP(__name, "min_focus_val") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)min_focus_val, 0));
    }

    // max_focus_val
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("max_focus_val", ParameterParserDataType::Int32, (double)max_focus_val, 0));
    }
    else if (PARAMETER_STRCMP(__name, "max_focus_val") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)max_focus_val, 0));
    }

    // smooth_alpha
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("smooth_alpha", ParameterParserDataType::Float, (double)smooth_alpha));
    }
    else if (PARAMETER_STRCMP(__name, "smooth_alpha") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)smooth_alpha));
    }

    // min_valid_confidence
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("min_valid_confidence", ParameterParserDataType::UInt32, (double)min_valid_confidence, 0));
    }
    else if (PARAMETER_STRCMP(__name, "min_valid_confidence") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)min_valid_confidence, 0));
    }

    return __result;
}

bool mod_depth10_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "depth10_rgn_data") == 0)
    {
        __result = depth10_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_depth10_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "depth10_rgn_data") == 0)
    {
        __result = depth10_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_depth10_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // depth10_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("depth10_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "depth10_rgn_data") == 0)
    {
        __result = depth10_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_depth10_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_depth10_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_depth10_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_depth10_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_depth10_aec_data") == 0)
    {
        if (__index < mod_depth10_aec_dataCount)
        {
            __result = mod_depth10_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_depth10_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_depth10_aec_data") == 0)
    {
        if (__index < mod_depth10_aec_dataCount)
        {
            __result = mod_depth10_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_depth10_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_depth10_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_depth10_aec_data", ParameterParserDataType::Structure, true, false, mod_depth10_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_depth10_aec_data") == 0)
    {
        if (__index < mod_depth10_aec_dataCount)
        {
            __result = mod_depth10_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_depth10_aec_dataCount));
        }
    }

    return __result;
}

bool mod_depth10_pre_scale_ratio_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_depth10_pre_scale_ratio_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_depth10_pre_scale_ratio_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // pre_scale_ratio_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pre_scale_ratio_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_trigger") == 0)
    {
        __result = pre_scale_ratio_trigger.GetInfo(&__path[__pos], __info);
    }

    // pre_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("pre_scale_ratio_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "pre_scale_ratio_data") == 0)
    {
        __result = pre_scale_ratio_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_depth10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_depth10_hdr_aec_data") == 0)
    {
        if (__index < mod_depth10_hdr_aec_dataCount)
        {
            __result = mod_depth10_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_depth10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_depth10_hdr_aec_data") == 0)
    {
        if (__index < mod_depth10_hdr_aec_dataCount)
        {
            __result = mod_depth10_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_depth10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_depth10_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_depth10_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_depth10_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_depth10_hdr_aec_data") == 0)
    {
        if (__index < mod_depth10_hdr_aec_dataCount)
        {
            __result = mod_depth10_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_depth10_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool chromatix_depth10_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_depth10_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_depth10_pre_scale_ratio_dataCount)
        {
            __result = mod_depth10_pre_scale_ratio_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_depth10_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_depth10_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_depth10_pre_scale_ratio_dataCount)
        {
            __result = mod_depth10_pre_scale_ratio_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_depth10_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_depth10_pre_scale_ratio_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_depth10_pre_scale_ratio_data", ParameterParserDataType::Structure, true, false, mod_depth10_pre_scale_ratio_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_depth10_pre_scale_ratio_data") == 0)
    {
        if (__index < mod_depth10_pre_scale_ratio_dataCount)
        {
            __result = mod_depth10_pre_scale_ratio_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_depth10_pre_scale_ratio_dataCount));
        }
    }

    return __result;
}

bool chromatix_depth10Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_depth10_reserve") == 0)
    {
        __result = chromatix_depth10_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_depth10_core") == 0)
    {
        __result = chromatix_depth10_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_depth10Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_depth10_reserve") == 0)
    {
        __result = chromatix_depth10_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_depth10_core") == 0)
    {
        __result = chromatix_depth10_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_depth10Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // chromatix_depth10_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_depth10_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_depth10_reserve") == 0)
    {
        __result = chromatix_depth10_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_depth10_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_depth10_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_depth10_core") == 0)
    {
        __result = chromatix_depth10_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_depth10Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_depth10Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_depth10Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_depth10Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_depth10Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_depth10Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_depth10Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 3; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_depth10Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 3)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_depth10Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 3));
    }

    return __result;
}

bool chromatix_depth10Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_depth10Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_depth10Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_depth10Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_pre_scale_ratio):
            enumValue = chromatix_depth10Type::control_variablesStruct::control_var_typeEnum::control_pre_scale_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_depth10Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_depth10TypeClass::chromatix_depth10TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_depth10_reserve);
    PARAMETER_INITIALIZE(chromatix_depth10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_depth10TypeClass::chromatix_depth10TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_depth10_reserve);
    PARAMETER_INITIALIZE(chromatix_depth10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_depth10TypeClass::~chromatix_depth10TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_depth10TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "depth10_eva")) == 0)
    {
        name = "depth10_eva";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(top);
    PARAMETER_INITIALIZE(reprojection);
    PARAMETER_INITIALIZE(calc_focus_disparity);
    PARAMETER_INITIALIZE(calc_focus_roi);

    result = top.Load(entry, alignment);
    if (result)
    {
        result = reprojection.Load(entry, alignment);
    }
    if (result)
    {
        result = calc_focus_disparity.Load(entry, alignment);
    }
    if (result)
    {
        result = calc_focus_roi.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_reserveType_topStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::topStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(dfs_width_tab);
    PARAMETER_INITIALIZE(dfs_height_tab);
    PARAMETER_INITIALIZE(dfs_max_extra_scale_x);
    PARAMETER_INITIALIZE(dfs_max_extra_scale_y);
    PARAMETER_INITIALIZE(aux_margin_ratio);
    PARAMETER_INITIALIZE(reserved7);
    PARAMETER_INITIALIZE(reserved8);
    PARAMETER_INITIALIZE(reserved9);
    PARAMETER_INITIALIZE(reserved10);

    result = dfs_width_tab.Load(entry, alignment);
    if (result)
    {
        result = dfs_height_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, dfs_max_extra_scale_x, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dfs_max_extra_scale_y, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, aux_margin_ratio, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved7, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved8, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved9, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved10, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_reserveType_topStruct_dfs_width_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::topStruct::dfs_width_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(dfs_width);

    result = entry->ReadArray(dfs_width, 3, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_reserveType_topStruct_dfs_height_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::topStruct::dfs_height_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(dfs_height);

    result = entry->ReadArray(dfs_height, 3, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_reserveType_reprojectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::reprojectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ctc_lmc_lut_en);
    PARAMETER_INITIALIZE(ctc_lmc_depth_min);
    PARAMETER_INITIALIZE(ctc_lmc_depth_mult);
    PARAMETER_INITIALIZE(ctc_lmc_lut_data_tab);

    SYMBOL_TABLE_ENTRY_READ(entry, result, ctc_lmc_lut_en, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, ctc_lmc_depth_min, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, ctc_lmc_depth_mult, alignment)
    if (result)
    {
        result = ctc_lmc_lut_data_tab.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_reserveType_reprojectionStruct_ctc_lmc_lut_data_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::reprojectionStruct::ctc_lmc_lut_data_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(ctc_lmc_lut_data);

    result = entry->ReadArray(ctc_lmc_lut_data, 65, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_reserveType_calc_focus_disparityStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::calc_focus_disparityStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(focus_disparity_calc_mode);

    SYMBOL_TABLE_ENTRY_READ(entry, result, focus_disparity_calc_mode, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_reserveType_calc_focus_roiStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_reserveType::calc_focus_roiStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mask_size);

    SYMBOL_TABLE_ENTRY_READ(entry, result, mask_size, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load depth10_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool depth10_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(top);
    PARAMETER_INITIALIZE(calc_focus_roi);

    result = top.Load(entry, alignment);
    if (result)
    {
        result = calc_focus_roi.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load depth10_rgn_dataType_topStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool depth10_rgn_dataType::topStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(reserved1);
    PARAMETER_INITIALIZE(reserved2);
    PARAMETER_INITIALIZE(reserved3);
    PARAMETER_INITIALIZE(reserved4);
    PARAMETER_INITIALIZE(reserved5);
    PARAMETER_INITIALIZE(reserved6);

    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved1, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved2, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved3, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved4, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved5, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved6, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load depth10_rgn_dataType_calc_focus_roiStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool depth10_rgn_dataType::calc_focus_roiStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(min_focus_val);
    PARAMETER_INITIALIZE(max_focus_val);
    PARAMETER_INITIALIZE(smooth_alpha);
    PARAMETER_INITIALIZE(min_valid_confidence);

    SYMBOL_TABLE_ENTRY_READ(entry, result, min_focus_val, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, max_focus_val, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, smooth_alpha, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, min_valid_confidence, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_depth10_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_depth10_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(depth10_rgn_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = depth10_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_depth10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_depth10_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_depth10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_depth10_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_depth10_aec_data);


    // Reading Array mod_depth10_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_depth10_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_depth10_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_depth10_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_depth10_aec_dataDupInfo = pointerEntry->GetDupObject(mod_depth10_aec_dataCount, file, line);
            if (mod_depth10_aec_dataDupInfo != nullptr && mod_depth10_aec_dataDupInfo->Object != nullptr)
            {
                mod_depth10_aec_data = (mod_depth10_aec_dataType*)mod_depth10_aec_dataDupInfo->Object;
                if (mod_depth10_aec_data == nullptr)
                {
                    if (mod_depth10_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_depth10_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_depth10_aec_dataDupInfo->File, mod_depth10_aec_dataDupInfo->Line, mod_depth10_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_depth10_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_depth10_aec_dataDupInfo->Line, mod_depth10_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_depth10_aec_data == nullptr)
            {
                if (result && mod_depth10_aec_dataCount > 0)
                {
                    mod_depth10_aec_data = PARAMETER_NEW mod_depth10_aec_dataType[mod_depth10_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_depth10_aec_data, mod_depth10_aec_dataCount, file, line);
                }
                if (!result || mod_depth10_aec_data == nullptr)
                {
                    if (mod_depth10_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_depth10_aec_data\n");
                    }
                    mod_depth10_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_depth10_aec_dataCount; i++)
                {
                    result = mod_depth10_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_depth10_aec_data == nullptr)
        {
            mod_depth10_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_depth10_pre_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_depth10_pre_scale_ratio_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(pre_scale_ratio_trigger);
    PARAMETER_INITIALIZE(pre_scale_ratio_data);

    result = pre_scale_ratio_trigger.Load(entry, alignment);
    if (result)
    {
        result = pre_scale_ratio_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_depth10_pre_scale_ratio_dataType_pre_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_depth10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_depth10_hdr_aec_data);


    // Reading Array mod_depth10_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_depth10_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_depth10_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_depth10_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_depth10_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_depth10_hdr_aec_dataCount, file, line);
            if (mod_depth10_hdr_aec_dataDupInfo != nullptr && mod_depth10_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_depth10_hdr_aec_data = (mod_depth10_hdr_aec_dataType*)mod_depth10_hdr_aec_dataDupInfo->Object;
                if (mod_depth10_hdr_aec_data == nullptr)
                {
                    if (mod_depth10_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_depth10_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_depth10_hdr_aec_dataDupInfo->File, mod_depth10_hdr_aec_dataDupInfo->Line, mod_depth10_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_depth10_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_depth10_hdr_aec_dataDupInfo->Line, mod_depth10_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_depth10_hdr_aec_data == nullptr)
            {
                if (result && mod_depth10_hdr_aec_dataCount > 0)
                {
                    mod_depth10_hdr_aec_data = PARAMETER_NEW mod_depth10_hdr_aec_dataType[mod_depth10_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_depth10_hdr_aec_data, mod_depth10_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_depth10_hdr_aec_data == nullptr)
                {
                    if (mod_depth10_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_depth10_hdr_aec_data\n");
                    }
                    mod_depth10_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_depth10_hdr_aec_dataCount; i++)
                {
                    result = mod_depth10_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_depth10_hdr_aec_data == nullptr)
        {
            mod_depth10_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_depth10_pre_scale_ratio_data);


    // Reading Array mod_depth10_pre_scale_ratio_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_depth10_pre_scale_ratio_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_depth10_pre_scale_ratio_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_depth10_pre_scale_ratio_dataID = pointerEntry->ID;
            DupObjInfo* mod_depth10_pre_scale_ratio_dataDupInfo = pointerEntry->GetDupObject(mod_depth10_pre_scale_ratio_dataCount, file, line);
            if (mod_depth10_pre_scale_ratio_dataDupInfo != nullptr && mod_depth10_pre_scale_ratio_dataDupInfo->Object != nullptr)
            {
                mod_depth10_pre_scale_ratio_data = (mod_depth10_pre_scale_ratio_dataType*)mod_depth10_pre_scale_ratio_dataDupInfo->Object;
                if (mod_depth10_pre_scale_ratio_data == nullptr)
                {
                    if (mod_depth10_pre_scale_ratio_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_depth10_pre_scale_ratio_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_depth10_pre_scale_ratio_dataDupInfo->File, mod_depth10_pre_scale_ratio_dataDupInfo->Line, mod_depth10_pre_scale_ratio_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_depth10_pre_scale_ratio_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_depth10_pre_scale_ratio_dataDupInfo->Line, mod_depth10_pre_scale_ratio_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_depth10_pre_scale_ratio_data == nullptr)
            {
                if (result && mod_depth10_pre_scale_ratio_dataCount > 0)
                {
                    mod_depth10_pre_scale_ratio_data = PARAMETER_NEW mod_depth10_pre_scale_ratio_dataType[mod_depth10_pre_scale_ratio_dataCount];
                    (void)pointerEntry->SetDupObject(mod_depth10_pre_scale_ratio_data, mod_depth10_pre_scale_ratio_dataCount, file, line);
                }
                if (!result || mod_depth10_pre_scale_ratio_data == nullptr)
                {
                    if (mod_depth10_pre_scale_ratio_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_depth10_pre_scale_ratio_data\n");
                    }
                    mod_depth10_pre_scale_ratio_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_depth10_pre_scale_ratio_dataCount; i++)
                {
                    result = mod_depth10_pre_scale_ratio_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_depth10_pre_scale_ratio_data == nullptr)
        {
            mod_depth10_pre_scale_ratio_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_depth10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_depth10_reserve);
    PARAMETER_INITIALIZE(chromatix_depth10_core);

    result = module_version.Load(entry, alignment);
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_depth10_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_depth10_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 3; i++)
    {
        result = chromatix_depth10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_depth10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_depth10_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_depth10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_depth10_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_depth10_aec_data))
    {
        PARAMETER_DELETE[] mod_depth10_aec_data;
    }
    mod_depth10_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_depth10_pre_scale_ratio_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_depth10_pre_scale_ratio_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    pre_scale_ratio_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_depth10_pre_scale_ratio_dataType_pre_scale_ratio_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_depth10_pre_scale_ratio_dataType::pre_scale_ratio_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_depth10_hdr_aec_dataCount; i++)
    {
        mod_depth10_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_depth10_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_depth10_hdr_aec_data;
    }
    mod_depth10_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_depth10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_depth10_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_depth10_pre_scale_ratio_dataCount; i++)
    {
        mod_depth10_pre_scale_ratio_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_depth10_pre_scale_ratio_data))
    {
        PARAMETER_DELETE[] mod_depth10_pre_scale_ratio_data;
    }
    mod_depth10_pre_scale_ratio_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_depth10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_depth10Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_depth10_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_depth10Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_depth10Type::Release()
{
    ((chromatix_depth10TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_depth10Type::GetModified()
{
    return ((chromatix_depth10TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_depth10TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_depth10TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_depth10TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_depth10TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_depth10TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_depth10TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_depth10TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_depth10TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_depth10TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_depth10TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_depth10TypeClass::Release()
{
    ParameterModule::Release();
}

DEPTH_1_0_0_NAMESPACE_END
